.. pychemia documentation master file, created by
   sphinx-quickstart on Wed May 18 13:34:29 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Pychemia's documentation
========================

Contents:

.. toctree::
   :maxdepth: 4

   1.Introduction
   2.Installation
   3.First_steps
   4.Tutorials
   5.PyChemiaAPI
   6.Contributors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

